#[unsafe(no_mangle)]pub unsafe extern "C" fn pselect(
nfds: c_int,
readfds: *mut fd_set,
writefds: *mut fd_set,
exceptfds: *mut fd_set,
timeout: *const timespec,
sigmask: *const sigset_t,
) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/pselect.html.
Examines the file descriptor sets whose addresses are passed in the
readfds, writefds and errorfds parameters to see whether some of
their descriptors are ready for reading, ready for writing, or have an
exceptional condition pending, respectively.
timeout is given in seconds and nanoseconds as represented by timespec.
Upon success, returns the total number of bits set in the bit masks. Upon
failure, returns -1 and sets errno to indicate the error.